@@ -1,53 +1,72 @@
 package Egg::Plugin::SessionKit::Store::Base64;
 #
-# Copyright (C) 2007 Bee Flag, Corp, All Rights Reserved.
 # Masatoshi Mizuno E<lt>lusheE<64>cpan.orgE<gt>
 #
-# $Id: Base64.pm 69 2007-03-26 02:15:26Z lushe $
+# $Id: Base64.pm 136 2007-05-12 12:49:36Z lushe $
 #
+
+=head1 NAME
+
+Egg::Plugin::SessionKit::Store::Base64 - Session data is made a text for preservation.
+
+=head1 SYNOPSIS
+
+  use Egg qw/ SessionKit /;
+  
+  __PACKAGE__->mk_eggstartup(
+    .......
+    ...
+    MODEL => [ [ DBI => { ... } ] ],
+    
+    plugin_session => {
+      store => {
+        name       => 'Base64',
+        },
+      .......
+      ...
+      },
+    );
+
+=head1 DESCRIPTION
+
+The means to make the session data a text for preservation is offered.
+
+=cut
 use strict;
+use warnings;
 use Storable qw(nfreeze thaw);
 use MIME::Base64;
 
-our $VERSION= '0.01';
+our $VERSION= '2.00';
 
-sub store_decode {
-	my $ss  = shift;
-	my $data= shift || return 0;
-	thaw(decode_base64($$data));
-}
+=head1 METHODS
+
+=head2 store_encode
+
+The session data is made a text.
+
+=cut
 sub store_encode {
 	my $ss  = shift;
 	my $data= shift || return 0;
 	encode_base64(nfreeze($data));
 }
 
-1;
+=head2 store_decode
 
-__END__
+The session data made a text is restored.
 
-=head1 NAME
-
-Egg::Plugin::SessionKit::Store::Base64 - The session data is treated with Base64.
-
-=head1 SYNOPSIS
-
-Configuration.
-
-  plugin_session=> {
-    store=> { name=> 'Base64' },
-    },
-
-=over 4
-
-=item store_decode, store_encode,
-
-These methods are called from the base module.
-
-=back
+=cut
+sub store_decode {
+	my $ss  = shift;
+	my $data= shift || return 0;
+	thaw(decode_base64($$data));
+}
 
 =head1 SEE ALSO
 
+L<Storable>,
+L<MIME::Base64>,
 L<Egg::Plugin::SessionKit>,
 L<Egg::Release>,
 
@@ -64,3 +83,5 @@ it under the same terms as Perl itself, either Perl version 5.8.6 or,
 at your option, any later version of Perl 5 you may have available.
 
 =cut
+
+1;
